@@ -74,7 +74,7 @@ class EdgeAttributeView(AttributeView, collections.MutableMapping):
 
 
 class Graph(Datastructure):
-    """Definition of a graph.
+    """Base graph data structure for describing the topological relationships between nodes connected by edges.
 
     Attributes
     ----------
@@ -87,12 +87,20 @@ class Graph(Datastructure):
         corresponds to a key in the node dictionary, and maps to a dictionary
         with connected nodes. In the latter, the keys are again references
         to items in the node dictionary, and the values are dictionaries
-        of edge attributes.
+        of edge attributes. For example, an edge between node 1 and node 2 is represented as follows
+        ``Graph.edge[1][2] -> {...}``
     adjacency : dict of dict
-        A half-edge dictionary, which keeps track of
-        undirected adjacencies.
+        The edges of the graph are directed.
+        The undirected connectivity information is represented in the adjacency dict.
     attributes : dict
-        A dictionary of miscellaneous information about the network.
+        A dictionary of miscellaneous information about the graph.
+    default_node_attributes : dict
+        A dictionary mapping node attribute names to their default values.
+    default_edge_attributes : dict
+        A dictionary mapping edge attribute names to their default values.
+    data : dict
+        A dictionary representing the essential data of a graph that can be used in serialization
+        processes.
 
     Examples
     --------
@@ -103,6 +111,7 @@ class Graph(Datastructure):
 
     def __init__(self):
         super(Graph, self).__init__()
+        self._max_int_key = -1
         self.attributes = {'name': 'Graph'}
         self.node = {}
         self.edge = {}
@@ -159,7 +168,8 @@ class Graph(Datastructure):
                 'edge_attributes': self.default_edge_attributes,
                 'node': {},
                 'edge': {},
-                'adjacency': {}}
+                'adjacency': {},
+                'max_int_key': self._max_int_key}
 
         for key in self.node:
             data['node'][repr(key)] = self.node[key]
@@ -189,6 +199,7 @@ class Graph(Datastructure):
         edge = data.get('edge') or {}
         adjacency = data.get('adjacency') or {}
 
+        self._max_int_key = data.get('max_int_key')
         self.attributes.update(attributes)
         self.default_node_attributes.update(default_node_attributes)
         self.default_edge_attributes.update(default_edge_attributes)
